==> apb-project_2.12-2.1.2-sources.jar: org/mulesoft/apb/project/internal/model/ProjectBase.scala <==
package org.mulesoft.apb.project.internal.model

import amf.core.client.scala.model.{BoolField, DateField, IntField, StrField}
import amf.shapes.client.scala.model.domain.jsonldinstance.JsonLDObject
import org.mulesoft.apb.project.client.scala.model.descriptor.{Gav, ProjectDependency}
import org.mulesoft.apb.project.internal.model.ProjectDescriptorModel._
import org.mulesoft.apb.project.internal.model.descriptor.ProjectDependencyModel.{AssetId, Classifier, GroupId, Version}
import org.mulesoft.common.time.SimpleDateTime

trait ProjectBase extends UnwrappedFields {

  private implicit def dependencyConversion(objs: Seq[JsonLDObject]): Seq[ProjectDependency] =
    objs.map(ProjectDependency.apply)

  def name(): String = get[StrField](ProjectDescriptorModel.Name)

  def gav(): Gav = getGav

  def classifier(): Option[String] = get[StrField](Classifier)

  def tags(): Seq[String] = get[Seq[StrField]](Tags)

  def apiVersion(): Option[String] = get[StrField](ApiVersion)

  def organizationId(): Option[String] = get[StrField](OrganizationId)

  def dependencies(): Seq[ProjectDependency] = get[Seq[JsonLDObject]](Dependencies)

  def status(): Option[String] = get[StrField](Status)

  def createdAt(): Option[SimpleDateTime] = get[DateField](CreatedAt)

  def createdBy(): Option[String] = get[StrField](CreatedBy)

  def updatedAt(): Option[SimpleDateTime] = get[DateField](UpdatedAt)

  def customFields(): Seq[String] = get[Seq[StrField]](CustomFields)

  def keyValueTags(): Seq[String] = get[Seq[StrField]](KeyValueTags)

  def tenantId(): Option[String] = get[StrField](TenantId)

  def categories(): Seq[String] = get[Seq[StrField]](Categories)

  def `type`(): Option[String] = get[StrField](TypeField)

  def majorVersionComponent(): Option[Int] = get[IntField](MajorVersionComponent)

  def minorVersionComponent(): Option[Int] = get[IntField](MinorVersionComponent)

  def patchVersionComponent(): Option[Int] = get[IntField](PatchVersionComponent)

  def apiId(): Option[String] = get[StrField](ApiId)

  def projectType(): Option[String] = get[StrField](ProjectType)

  def contactName(): Option[String] = get[StrField](ContactName)

  def contactEMail(): Option[String] = get[StrField](ContactEMail)

  def description: Option[String] = get[StrField](Description)

  def systemUpdateTime(): Option[SimpleDateTime] = get[DateField](SystemUpdatedAt)

  def projectETag(): Option[String] = get[StrField](ProjectETag)

  def isDocumented(): Option[Boolean] = get[BoolField](IsDocumented)

  private def getGav: Gav = {
    val groupId: String = get[StrField](GroupId)
    val assetId: String = get[StrField](AssetId)
    val version: String = get[StrField](Version)
    Gav(groupId, assetId, version)
  }
}

==> apb-project_2.12-2.2.3-2-sources.jar: org/mulesoft/apb/project/internal/model/ProjectBase.scala <==
package org.mulesoft.apb.project.internal.model

import amf.core.client.scala.model.{BoolField, DateField, IntField, StrField}
import amf.shapes.client.scala.model.domain.jsonldinstance.JsonLDObject
import org.mulesoft.apb.project.client.scala.model.descriptor.{
  Gav,
  ProjectDependency,
  AttributeEntry,
  FilePackaging => FilePackagingObj
}
import org.mulesoft.apb.project.internal.model.ProjectDescriptorModel._
import org.mulesoft.apb.project.internal.model.descriptor.ProjectDependencyModel.{AssetId, Classifier, GroupId, Version}
import org.mulesoft.common.time.SimpleDateTime

trait ProjectBase extends UnwrappedFields {

  private implicit def dependencyConversion(objs: Seq[JsonLDObject]): Seq[ProjectDependency] =
    objs.map(ProjectDependency.apply)

  private implicit def attributeConversion(objs: Seq[JsonLDObject]): Seq[AttributeEntry] =
    objs.map(AttributeEntry.apply)

  private implicit def filePackagingConversion(objs: Seq[JsonLDObject]): Seq[FilePackagingObj] =
    objs.map(FilePackagingObj.apply)

  def name(): String = get[StrField](ProjectDescriptorModel.Name)

  def gav(): Gav = getGav

  def classifier(): Option[String] = get[StrField](Classifier)

  def tags(): Seq[String] = get[Seq[StrField]](Tags)

  def apiVersion(): Option[String] = get[StrField](ApiVersion)

  def organizationId(): Option[String] = get[StrField](OrganizationId)

  def dependencies(): Seq[ProjectDependency] = get[Seq[JsonLDObject]](Dependencies)

  def status(): Option[String] = get[StrField](Status)

  def createdAt(): Option[SimpleDateTime] = get[DateField](CreatedAt)

  def createdBy(): Option[String] = get[StrField](CreatedBy)

  def updatedAt(): Option[SimpleDateTime] = get[DateField](UpdatedAt)

  def customFields(): Seq[String] = get[Seq[StrField]](CustomFields)

  def keyValueTags(): Seq[String] = get[Seq[StrField]](KeyValueTags)

  def tenantId(): Option[String] = get[StrField](TenantId)

  def categories(): Seq[String] = get[Seq[StrField]](Categories)

  def `type`(): Option[String] = get[StrField](TypeField)

  def majorVersionComponent(): Option[Int] = get[IntField](MajorVersionComponent)

  def minorVersionComponent(): Option[Int] = get[IntField](MinorVersionComponent)

  def patchVersionComponent(): Option[Int] = get[IntField](PatchVersionComponent)

  def apiId(): Option[String] = get[StrField](ApiId)

  def projectType(): Option[String] = get[StrField](ProjectType)

  def contactName(): Option[String] = get[StrField](ContactName)

  def contactEMail(): Option[String] = get[StrField](ContactEMail)

  def description: Option[String] = get[StrField](Description)

  def systemUpdateTime(): Option[SimpleDateTime] = get[DateField](SystemUpdatedAt)

  def projectETag(): Option[String] = get[StrField](ProjectETag)

  def hasDocumentation(): Option[Boolean] = get[BoolField](HasDocumentation)

  def apiUrn(): Option[String] = get[StrField](ApiUrn)

  def attributes(): Seq[AttributeEntry] = get[Seq[JsonLDObject]](Attribute)

  def managedTags(): Seq[String] = get[Seq[StrField]](ManagedTag)

  def filePackaging(): Seq[FilePackagingObj] = get[Seq[JsonLDObject]](FilePackaging)

  private def getGav: Gav = {
    val groupId: String = get[StrField](GroupId)
    val assetId: String = get[StrField](AssetId)
    val version: String = get[StrField](Version)
    Gav(groupId, assetId, version)
  }
}
